/* -*- pftp-c -*- */
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#if HAVE_STDLIB_H
# include <stdlib.h>
#endif
#if HAVE_STRING_H
# include <string.h>
#endif
#if HAVE_UNISTD_H
# include <unistd.h>
#endif
#if HAVE_STDIO_H
# include <stdio.h>
#endif
#ifdef WITH_DMALLOC
#include <dmalloc.h>
#endif

#include "set_utils.h"

const char *yesno(int val)
{
    switch(val)
    {
    case 1:
	return "yes";
    case 0:
 	return "no";
    default:
    case -1:
	return "";
    }
}

void longval(char **str, long val)
{
    (*str) = realloc((*str), 20);
    snprintf((*str), 20, "%ld", val);    
}

void ulongval(char **str, unsigned long val)
{
    (*str) = realloc((*str), 20);
    snprintf((*str), 20, "%lu", val);
}
